# SimpleMC
A python API for the game Minecraft.



**Docs**
  
  Coming soon.

**Example**
```python
import simplemc
from simplemc import Users


user = Users.check("74a202a4eb21470fb5a63a0c985b0ddc") # Add any UUID.
print(user)

# Check if a user exists by uuid.
